@@ -1669,6 +1669,13 @@ pred_head(Head) -->                     % Postfix operators
     html([ var(class=arglist, \pred_arg(Arg, 1)),
            ' ', b(class=pred, Functor)
          ]).
+pred_head({Head}) -->
+    !,
+    html([ b(class=pred, '{'),
+           var(class=arglist,
+               \pred_args([Head], 1)),
+           b(class=pred, '}')
+         ]).
 pred_head(Head) -->                     % Plain terms
     { Head =.. [Functor|Args] },
     html([ b(class=pred, Functor),
@@ -1879,6 +1886,45 @@ canonical_pi(Name//Arity, Name/Arity2, [Name, //, Arity]) :-
     !,
     Arity2 is Arity+2.
 
+%!  nopredref(+PI)//
+%
+%   Result of ``name/arity``, non-linking predicate indicator.
+
+nopredref(PI) -->
+    { canonical_pi(PI, _CPI, HTML)
+    },
+    !,
+    html(span(class=nopredref, HTML)).
+
+%!  flagref(+Flag)//
+%
+%   Reference to a Prolog flag.
+%
+%   @tbd generate a link to the Prolog website?
+
+flagref(Flag) -->
+    html(code(Flag)).
+
+%!  cite(+Citations)// is det.
+%
+%   Emit citations. This is indented to   allow  for [@cite1;@cite2] for
+%   generating LaTex.
+
+cite(Citations) -->
+    html('['), citations(Citations), html(']').
+
+citations([]) --> [].
+citations([H|T]) -->
+    citation(H),
+    (   {T==[]}
+    ->  []
+    ;   [';'],
+        citations(T)
+    ).
+
+citation(H) -->
+    html([@,H]).
+
 
 %!  manref(+NameArity, -HREF, +Options) is det.
 %
