@@ -342,8 +342,8 @@ rdf(S,P,O,G) :-
     post_graph(G, G0),
     post_object(O,O0).
 
-%!  rdf_has(?S, ?P, ?O) is nondet.
-%!  rdf_has(?S, ?P, ?O, -RealP) is nondet.
+%!  rdf_has(?S, +P, ?O) is nondet.
+%!  rdf_has(?S, +P, ?O, -RealP) is nondet.
 %
 %   Similar to rdf/3 and rdf/4, but   P  matches all predicates that
 %   are defined as an rdfs:subPropertyOf of   P. This predicate also
@@ -1259,6 +1259,17 @@ in_number(double, _Domain, _, Val, Val0) :-
     !,
     xsd_number_string(ValF, ValS),
     atom_string(Val0, ValS).
+in_number(decimal, _Domain, _, Val, Val0) :-
+    number(Val),
+    !,
+    ValF is float(Val),
+    atom_number(Val0, ValF).
+in_number(decimal, _Domain, _, Val, Val0) :-
+    atomic(Val),
+    xsd_number_string(Num, Val),
+    ValF is float(Num),
+    !,
+    atom_number(Val0, ValF).
 in_number(PrologType, _, _, Val, _) :-
     type_error(PrologType, Val).
 
@@ -1286,7 +1297,7 @@ error:has_type(nonpos, T):-
 
 xsd_numerical(xsd:byte,               between(-128,127),               integer).
 xsd_numerical(xsd:double,             float,                           double).
-xsd_numerical(xsd:decimal,            float,                           double).
+xsd_numerical(xsd:decimal,            float,                           decimal).
 xsd_numerical(xsd:float,              float,                           double).
 xsd_numerical(xsd:int,                between(-2147483648,2147483647), integer).
 xsd_numerical(xsd:integer,            integer,                         integer).
